package com.securecom;

import java.io.IOException;
import java.util.Set;

import android.app.Activity;
import android.os.AsyncTask;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.View.OnTouchListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.TextView;

import com.google.android.gcm.GCMRegistrar;
import com.google.api.client.extensions.android.http.AndroidHttp;
import com.google.api.client.http.HttpRequest;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.json.jackson.JacksonFactory;
import com.securecom.RegisterActivity.State;
import com.securecom.messageEndpoint.MessageEndpoint;
import com.securecom.messageEndpoint.model.CollectionResponseMessageData;
import com.securecom.messageEndpoint.model.MessageData;

/**
 * A fragment representing a single Chat detail screen. This fragment is either
 * contained in a {@link ChatListActivity} in two-pane mode (on tablets) or a
 * {@link ChatDetailActivity} on handsets.
 */
public class ChatDetailFragment extends Fragment {
	/**
	 * The fragment argument representing the item ID that this fragment
	 * represents.
	 */
	public static final String ARG_ITEM_ID = "item_id";

	private MessageEndpoint messageEndpoint;
	private String deviceId;
	
	private EditText textField;
	
	/**
	 * Mandatory empty constructor for the fragment manager to instantiate the
	 * fragment (e.g. upon screen orientation changes).
	 */
	public ChatDetailFragment() {
	}

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
	
		Bundle arguments = getArguments();
		deviceId = arguments.getString(ARG_ITEM_ID);

		MessageEndpoint.Builder endpointBuilder = new MessageEndpoint.Builder(
				AndroidHttp.newCompatibleTransport(), new JacksonFactory(),
				new HttpRequestInitializer() {
					public void initialize(HttpRequest httpRequest) {
					}
				});

		messageEndpoint = CloudEndpointUtils.updateBuilder(endpointBuilder).build();
	}

	@Override
	public View onCreateView(LayoutInflater inflater, ViewGroup container,
			Bundle savedInstanceState) {
		View rootView = inflater.inflate(R.layout.fragment_chat_detail,
				container, false);
		
		textField = (EditText) rootView.findViewById(R.id.messageEdit);

		new QueryMessagesTask(rootView, messageEndpoint).execute();
		
		OnTouchListener sendMessageListener = new OnTouchListener() {
			@Override
			public boolean onTouch(View v, MotionEvent event) {
				switch (event.getAction() & MotionEvent.ACTION_MASK) {
				case MotionEvent.ACTION_DOWN:
					String message = textField.getText().toString();
					textField.getText().clear();
					try {
						messageEndpoint.sendMessageTo(message, deviceId).execute();
					} catch (IOException e) {
						// TODO Auto-generated catch block
						e.printStackTrace();
					}
					return true;
				case MotionEvent.ACTION_UP:
					return true;
				default:
					return false;
				}
			}
		};

		Button sendMsgButton = (Button) rootView.findViewById(R.id.sendMsgButton);
		sendMsgButton.setOnTouchListener(sendMessageListener);
		
		return rootView;
	}
	
	/*
	 * Need to run this in background so we don't hold up the UI thread, this
	 * task will ask the App Engine backend for the last 5 messages sent to it
	 */
	private class QueryMessagesTask extends
			AsyncTask<Void, Void, CollectionResponseMessageData> {
		Exception exceptionThrown = null;
		MessageEndpoint messageEndpoint;
		View rootView;

		public QueryMessagesTask(View rootView,
				MessageEndpoint messageEndpoint) {
			this.rootView = rootView;
			this.messageEndpoint = messageEndpoint;
		}

		@Override
		protected CollectionResponseMessageData doInBackground(Void... params) {
			try {
				CollectionResponseMessageData messages = messageEndpoint
						.listMessages().setLimit(5).execute();
				return messages;
			} catch (IOException e) {
				exceptionThrown = e;
				return null;
				// Handle exception in PostExecute
			}
		}

		protected void onPostExecute(CollectionResponseMessageData messages) {
			// Check if exception was thrown
			if (exceptionThrown != null) {
				Log.e(RegisterActivity.class.getName(),
						"Exception when listing Messages", exceptionThrown);
			} else {
				ListView messageView = (ListView) rootView.findViewById(R.id.chat_detail_list);
				MessageDataAdapter messageAdapter = new MessageDataAdapter(
						getActivity(), android.R.layout.simple_list_item_1, android.R.id.text1,
						messages.getItems());
				messageView.setAdapter(messageAdapter);
			}
		}
	}
}
